import express, { Request, Response } from 'express';
import { prisma, __path, log } from '../../index.js';

export default (req: Request, res: Response) => {
	// If method is get, render the page
	if (req.method === 'GET') {
		// Render the page
		prisma.category
		.findMany({})
		.then((items) => {
			// Count amount of total items
			res.render(__path + '/src/frontend/categoryManager.eta.html', { items: items });
		})
		.catch((err) => {
			console.error(err);
			res.status(500).render(__path + '/src/frontend/errors/dbError.eta.html', { error: err });
		});
	} else {
		console.log(req.body);
		// Check if required fields are filled in
		if (!req.body.name || !req.body.description) {
			res.status(400).render(__path + '/src/frontend/errors/400.eta.html');
			return;
		}
		
		if(!req.body.editCategoryModalIsEdit) {
			console.log('is not edit');
		// Save data to category table
		prisma.category.create({
			data: {
				name: req.body.name,
				description: req.body.description,
			},
		})
		.then(() => {
			res.redirect('/allCategories');
		})
		.catch((err) => {
			// TODO Catch if is a duplicate error and show a message to the user
			log.db.error(err);
			res.status(500).render(__path + '/src/frontend/errors/dbError.eta.html', { error: err });
		});
		} else {
			// Save data to category table
		prisma.category.update({
			where: {
				id: parseInt(req.body.editCategoryModalId)
			},
			data: {
				name: req.body.name,
				description: req.body.description,
			},
		})
		.then(() => {
			res.redirect('/allCategories');
		})
		.catch((err) => {
			// TODO Catch if is a duplicate error and show a message to the user
			log.db.error(err);
			res.status(500).render(__path + '/src/frontend/errors/dbError.eta.html', { error: err });
		});
		}
	}
	
};
